@@ -24,18 +24,24 @@
 @interface Body: Node {
     dBodyID body;
     dGeomID geom;
+    dSpaceID space;
 
-    dVector3 velocity, spin;
+    dReal velocity[3], spin[3];
     dMass mass;
-}
 
--(dSpaceID) space;
+    int clamped, encapsulated;
+}
 
 -(dBodyID) body;
 -(dGeomID) geom;
+-(dSpaceID) space;
 
--(void) addBody: (id) node;
--(void) removeBody: (id) node;
+-(void) fasten;
+-(void) release;
+-(void) insertInto: (dSpaceID) new;
+
+-(dReal *) velocity;
+-(dReal *) spin;
 
 @end
 
