@@ -17,9 +17,9 @@
 #ifndef _COLUMN_H_
 #define _COLUMN_H_
 
-#include "container.h"
+#include "widget.h"
 
-@interface Column: Container {
+@interface Column: Widget {
 }
 @end
 
