@@ -17,9 +17,9 @@
 #ifndef _DISPLAY_H_
 #define _DISPLAY_H_
 
-#include "node.h"
+#include "widget.h"
 
-@interface Display: Node {
+@interface Display: Widget {
 }
 
 @end
