@@ -28,7 +28,7 @@
 }
 
 -(Face *) initFromFile: (const char *)name;
--(id)layoutString: (const char *)string;
+-(void)layoutString: (const char *)string intoTexture: (GLint) name;
 @end
 
 #endif
