@@ -22,11 +22,11 @@
 {
 }
 
--(void) traverse: (lua_State *)L
+-(void) traverse
 {
     [self draw];
     
-    [super traverse: L];
+    [super traverse];
 }
 
 @end
