@@ -25,10 +25,9 @@
     dJointID joint;
 }
 
--(dWorldID) world;
 -(dJointID) joint;
--(void) get: (lua_State *)L;
--(void) set: (lua_State *)L;
+-(void) get;
+-(void) set;
 
 @end
 
