@@ -22,7 +22,8 @@
 #include "joint.h"
 
 @interface Slider: Joint {
-    double axis[3], motor[2], stops[2], hardness[2], tolerance, bounce;
+    double axis[3], motor[2], stops[2], hardness[2];
+    double fudge, tolerance, bounce;
 }
 
 @end
