@@ -19,16 +19,11 @@
 
 #include <lua.h>
 #include <ode/ode.h>
-#include "node.h"
+#include "space.h"
 
-@interface System: Node {
-    dSpaceID space;
+@interface System: Space {
 }
 
--(dSpaceID) space;
--(void) addBody: (id) node;
--(void) removeBody: (id) node;
-
 @end
 
 #endif
