@@ -24,11 +24,8 @@
 @interface Timer: Node {
     struct timespec checkpoint;
 
-    double period, elapsed, delta;
-    int tick, fire;
-
-    int timedlink, timedunlink, timedprepare;
-    int timedtransform, timedtraverse, timedcleanup;
+    double period, elapsed, delta, count;
+    int tick;
 }
 @end
 
