@@ -17,4 +17,9 @@
 #include "transform.h"
 
 @implementation Transform
+-(void) transform
+{
+    [super transform];
+}
+
 @end
